From: Tom Lane <tgl@sss.pgh.pa.us>
To: Pavel Borisov <pashkin.elfe@gmail.com>
Cc: Alexander Lakhin <exclusion@gmail.com>
Cc: pgsql-bugs@lists.postgresql.org
Subject: Re: BUG #16329: Valgrind detects an invalid read when building a gist index with buffering
Date: Mon, 12 Oct 2020 18:16:52 -0400
Message-ID: <3395318.1602541012@sss.pgh.pa.us> (raw)
In-Reply-To: <CALT9ZEECCV5m7wvxg46PC-7x-EybUmnpupBGhSFMoAAay+r6HQ@mail.gmail.com>
References: <16329-7a6aa9b6fa1118a1@postgresql.org>
<ca1f896b-e5d1-53a7-5bc3-9451ab9aca22@gmail.com>
<e91e45fd-a614-bb87-e9fc-c556c2b95fe5@gmail.com>
<3dda6945-c147-5afc-7720-38ec6848dafa@gmail.com>
<10261.1588705157@sss.pgh.pa.us>
<93ca4540-0016-8217-2b31-535613499987@gmail.com>
<06f117b8-bbc1-4190-d204-ef329121cbca@gmail.com>
<CALT9ZEECCV5m7wvxg46PC-7x-EybUmnpupBGhSFMoAAay+r6HQ@mail.gmail.com>
Pavel Borisov <pashkin.elfe@gmail.com> writes:
> Also, there is a minor correction for the case of covering index where only
> part of the columns are keys, others are just INCLUDE columns.
Yeah, that's clearly a bug, and it reinforces the point about wanting
more thorough test coverage of this area.
I pushed the bug fix, but not yet the test addition, because I'm not
very happy about the latter:
1. It nearly triples the runtime of gist.sql, from ~650 ms to ~1700 ms
on my machine. That's a pretty bad increase for something we're
proposing to drop into the core regression tests. Given that this is
hardly the only index build in that test, I wonder why it's so much
(but I did not look for the reason).
2. The test exposed the gistRelocateBuildBuffersOnSplit bug only about
one time in ten for me. I suppose this is due to the random split
choices gistchoose makes for equally-good tuples, so it's not terribly
surprising; but it is problematic for a test that we're hoping to use
to provide reliable code coverage.
I'm not really sure what we could do about #2. Perhaps, instead of
relying on random(), we could make gistchoose() use our own PRNG and
then invent a debugging function that forces the seed to a known value.
(GEQO already does something similar, although I'd not go as far as
exposing the seed as a GUC. Resetting it via some quick-hack C
function in regress.c would be enough IMO.) Or perhaps gist.sql could
be adjusted so that the test data is less full of equally-good tuples.
regards, tom lane
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-bugs@postgresql.org
Cc: tgl@sss.pgh.pa.us, pashkin.elfe@gmail.com, exclusion@gmail.com, pgsql-bugs@lists.postgresql.org
Subject: Re: BUG #16329: Valgrind detects an invalid read when building a gist index with buffering
In-Reply-To: <3395318.1602541012@sss.pgh.pa.us>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox